@@ -474,14 +474,14 @@ def move_single_ipynb(file_ipynb):
             os.makedirs(dir_ipynb)
         cmd_run = "git mv " + file_ipynb + " " + dir_ipynb
         print(cmd_run)
-        cmd_ret = util.print_run_cmd(cmd_run)
+        cmd_ret = print_run_cmd(cmd_run)
     else:
         print("Can not find %s" % file_ipynb)
 
 
 def git_add_ipynb(file_ipynb):
     cmd_run = "git add " + file_ipynb
-    cmd_ret = util.print_run_cmd(cmd_run)
+    cmd_ret = print_run_cmd(cmd_run)
 
 
 def endswith(*endstring):
